<?php
/**
 * @copyright	Copyright (C) 2009-2014 ACYBA SARL - All rights reserved.
 * @license		http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */
defined('_JEXEC') or die('Restricted access');

/** This plugin allow you to create new custom fields type for Acymailing.
 * You will need 3 functions: one to create your field type and the two other to display your field.
 * Note that you can create several custom fields. In this case you will need to duplicate the two display functions for each field you create.
 */
class plgAcymailingExampleCF extends JPlugin{
	/** Creation of the custom field.
	 * You have to complete the two arrays with the description of your field. The keys representing your custom field has to be added in the name of the disply functions.
	 * 
	 * $allValues: (string) contains the title of the custom field which will be displayed in the list oof available fields.
	 * $allTypes: (array) contains the parameters you can display when editing your field in the custom field edition in Acymailing.
	 * 		This are the current option for default Acymailing custom fields. You are not forced to add one.
	 * 		Possible values are: multivalues, cols, rows, size, required, format, default, customtext, columnname, checkcontent, dbValues
	 *  
	 * You can create several custom fields here.
	 */
	function onAcyCreateField(&$allValues, &$allTypes){
		// First field
		$allValues["myCF"] = 'My custom field';
		$allTypes["myCF"] = array('required','size');

		// If you want to create more you can add here as many as you want.
		$allValues["CF2"] = 'My second CF';
		$allTypes["CF2"] = array();
	}

	/** Display the field in the custom field configuration or when the user can change the value (ie. for a dropdown list display the list for the user to choose among all the values)
	 * You have to create this function for each field you have created above. Change the name like this: 'onAcyDisplayField_' + the key of your custom field.
	 * 
	 * $field:(object) contains all data of the field (possible values, parameters we added above...)
	 * $value: value selected for the field
	 * $map: (string) name of the input/select... tag.
	 * $inside: (bool) display value inside or outside of the input
	 */
	 // For the example it will be an input type text
	function onAcyDisplayField_myCF($field, $value, $map, $inside){
		// Get the required parameter we added above
		$class= empty($field->required) ? 'class="inputbox"' : 'class="inputbox required"';

		// Get the size parameter we added above
		$style = array();
		if(!empty($field->options['size'])){
			$style = ' style="width:'.(is_numeric($field->options['size']) ? ($field->options['size'].'px') : $field->options['size']) . '"';
		}

		// Text displayed inside
		$placeholder = '';
		if($inside && !empty($field->fieldname)){
			$placeholder = 'placeholder="'. addslashes($field->fieldname).'"';
		}

		$id = str_replace(' ','_','field_'.$field->namekey);
		echo '<input id="'.$id.'" '.$style.' '.$placeholder.' type="text" '.$class.' name="'.$map.'" value="'.(!empty($value)?htmlspecialchars($value,ENT_COMPAT, 'UTF-8'):'').'" />';
	}


	/** Display the field in the listing or in the profile (not editable, just display the value registered).
	 * This function is not mandatory if the value is only text, it will be displayed automatically.
	 * $field: (object) contains all info of the field (value, parameters, options...)
	 * $value: value selected for the field
	 */
	function onAcyListingField_myCF($field, $value){
		echo 'Content of my custom field: '. nl2br($value);
	}

	// ------------------------------------------------------------------------------------------------------//
	// If you have created several fields
	// Display for the second field
	function onAcyDisplayField_CF2($field, $value, $map, $inside){
		// ...
	}
}
